@@ -1,3 +1,9 @@
+__title__ = 'django-lime.conf'
+__version__ = '0.3'
+__build__ = 0x000003
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__all__ = ('get_setting',)
+
 from django.conf import settings
 
 from lime import defaults
