@@ -1,3 +1,7 @@
+__title__ = 'django-lime.helpers'
+__version__ = '0.3'
+__build__ = 0x000003
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __all__ = ('site')
 
 from collections import namedtuple
